@@ -1,5 +1,54 @@
 # $Id$
 
+import xlmisc, gobject, common, time, xlmisc, urllib
+from gettext import gettext as _
+SCROBBLER_SESSION = None
+
+@common.threaded
+def submit_to_scrobbler(exaile, tr):
+    if tr.title == '' or tr.artist == '': return
+    if tr.type == 'lastfm': return
+   
+    if not SCROBBLER_SESSION: return
+    len = tr.duration
+    lt = time.gmtime(time.time())
+
+    date = "%02d-%02d-%02d %02d:%02d:%02d" % (lt[0], lt[1], lt[2],
+        lt[3], lt[4], lt[5])
+
+    xlmisc.log('Attempting to submit track %s to last.fm' % tr)
+    try:
+        SCROBBLER_SESSION(artist_name=tr.artist,
+            song_title=tr.title,
+            length=int(tr.duration),
+            date_played=date,
+            album=tr.album)
+    except:
+        xlmisc.log_exception()
+        gobject.idle_add(exaile.status.set_first, 
+            _("Failed to submit track to Last.fm."), 3000)
+
+def get_scrobbler_session(exaile, username="", password="", new=False): 
+    """
+        If there is no audio scrobbler session, one is created and returned,
+        else the current one is returned
+    """
+    global SCROBBLER_SESSION
+
+    if (SCROBBLER_SESSION == None or new) and \
+        (username != "" and password != ""):
+        xlmisc.log('Logging in to audioscrobbler')
+        SCROBBLER_SESSION = AudioScrobblerPost(username=username, 
+            password=password, client_name='exa')
+        SCROBBLER_SESSION.verbose = True
+        try:
+            SCROBBLER_SESSION.auth()
+        except:
+            xlmisc.log_exception()
+            gobject.idle_add(exaile.status.set_first,
+                _("Error logging into Last.fm."), 3000)
+            return None
+    return SCROBBLER_SESSION
 """
 ~~~~~~~~~~~
 PyScrobbler
@@ -296,7 +345,7 @@ audioscrobbler_request_host = 'ws.audioscrobbler.com'
 # AudioScrobblerPost configuration settings
 audioscrobbler_post_version = u'1.1'
 audioscrobbler_post_host = 'post.audioscrobbler.com'
-client_name = u'tst'
+client_name = u'exa'
 pyscrobbler_version = u'1.0' # This is set to 1.0 while we use
                              # client_name = u'tst' as we keep getting
                              # UPDATE responses with anything less.
@@ -766,17 +815,22 @@ class AudioScrobblerPost:
         count = 0
         for track in self.cache[:number]:
             for k in track.keys():
+                track[k] = urllib.quote(track[k].encode('utf-8'))
                 params[k % (count,)] = track[k]
         
         self.auth()
         params.update(self.auth_details)
-        postdata = urllib.urlencode(params)
+
+        postdata = '&'.join(['%s=%s' % (k, v) for k, v in params.iteritems()])
+#        postdata = urllib.urlencode(params)
         req = urllib2.Request(url=self.posturl, data=postdata)
         
         now = datetime.datetime.utcnow()
         interval = datetime.timedelta(seconds=self.interval)
         if self.last_post is not None and self.last_post + interval > now:
             time.sleep(self.interval)
+
+        xlmisc.log('-AUDIOSCROBBLER- %s' % postdata)
         try:
             url_handle = urllib2.urlopen(req)
         except urllib2.HTTPError, error:
